.. _all-salt.runners:

=========================
Full list of Salt runners
=========================

.. currentmodule:: salt.runners

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    jobs
    launchd
    manage
    network
